timeseria.datastructures
========================

.. automodule:: timeseria.datastructures

   
   
   

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
   
      Series
      
      Point
      TimePoint
      DataPoint
      DataTimePoint
      
      PointSeries
      TimePointSeries
      DataPointSeries
      DataTimePointSeries
      
      Slot
      TimeSlot
      DataSlot
      DataTimeSlot
      
      SlotSeries
      TimeSlotSeries
      DataSlotSeries
      DataTimeSlotSeries
   

   
   
   



